@@ -67,8 +67,21 @@ void Widget::setLocation()
     width = windowSize.width();
     height = windowSize.height();
 
-    x = (screenWidth - width);
-    y = 0;
+    if(!QSettings().contains("main/x_coord"))
+        QSettings().setValue("main/x_coord", -1);
+    x = QSettings().value("main/x_coord").toInt();
+
+    if(!QSettings().contains("main/y_coord"))
+        QSettings().setValue("main/y_coord", 0);
+    y = QSettings().value("main/y_coord").toInt();
+
+    if(x < 0 || x > (screenWidth - width)){
+        x = (screenWidth - width);
+    }
+
+    if(y < 0 || y > (screenHeight - height)){
+        y = (screenHeight - height);
+    }
 
     move(x, y);
 }
